/** Rill v0.0.700 https://www.npmjs.com/package/rill License: MIT*/
"use strict";
var Request, expect, parseURL;

parseURL = require("@rill/parse-url");

expect = require("./util/expect");


/*
 * Constructor that will normalize a request object.
 *
 * @param {Object} req
 * @constructor
 */

Request = (function() {
  function Request(req, ctx) {
    var key, ref, ref1, ref2, ref3, ref4, ref5, val;
    if (!(this instanceof Request)) {
      return new Request(req, ctx);
    }
    expect(req != null, "Could not create Request with an empty object.");
    expect(req.url != null, "Could not create a Request without a URL.");
    this._ctx = ctx;
    this.method = req.method;
    this.headers = req.headers;
    this.files = (ref = req.files) != null ? ref : [];
    this.body = (ref1 = req.body) != null ? ref1 : {};
    this.socket = req.socket;
    this.req = req;
    this.ip = (ref2 = (ref3 = this.headers["x-forwarded-for"]) != null ? ref3.split(",")[0] : void 0) != null ? ref2 : (ref4 = req.connection) != null ? ref4.remoteAddress : void 0;
    this.headers["referrer"] = this.headers["referer"];
    ref5 = parseURL(req.url, this);
    for (key in ref5) {
      val = ref5[key];
      this[key] = val;
    }
  }


  /*
  	 * Trigger another request that will redirect the browser and send a location change on the server.
  	 * If "back" is the url then it will attempt to redirect the user back a url, otherwise the alt will be used.
  	 *
  	 * @param {String} url
  	 * @param {String} alt
   */

  Request.prototype.redirect = function(url, alt) {
    if (url == null) {
      url = "back";
    }
    if (alt == null) {
      alt = "/";
    }
    return this.redirectURL = this._ctx.response.headers["location"] = (url !== "back" ? url : this.headers.referer || alt);
  };

  return Request;

})();

module.exports = Request;
